ModelBatchDecoder

Struct ModelBatchDecoder 

pub struct ModelBatchDecoder(/* private fields */);

Implementations

Source

impl ModelBatchDecoder

pub fn new( header: CityArrowHeader, projection: ProjectionLayout, options: &ImportOptions, ) -> Result<Self>

Errors

Returns an error when the schema version is not supported or the canonical projection is invalid.

pub fn push_batch( &mut self, table: CanonicalTable, batch: &RecordBatch, ) -> Result<()>

Errors

Returns an error when the batch order, schema, or data is invalid.

pub fn finish(self) -> Result<OwnedCityModel>

Errors

Returns an error when required tables are missing or reconstruction cannot finish successfully.