pub struct ModelBatchDecoder(/* private fields */);Implementations
Sourceimpl ModelBatchDecoder
impl ModelBatchDecoder
Sourcepub fn new(
header: CityArrowHeader,
projection: ProjectionLayout,
options: &ImportOptions,
) -> Result<Self>
pub fn new( header: CityArrowHeader, projection: ProjectionLayout, options: &ImportOptions, ) -> Result<Self>
Errors
Returns an error when the schema version is not supported or the canonical projection is invalid.
Sourcepub fn push_batch(
&mut self,
table: CanonicalTable,
batch: &RecordBatch,
) -> Result<()>
pub fn push_batch( &mut self, table: CanonicalTable, batch: &RecordBatch, ) -> Result<()>
Errors
Returns an error when the batch order, schema, or data is invalid.
Sourcepub fn finish(self) -> Result<OwnedCityModel>
pub fn finish(self) -> Result<OwnedCityModel>
Errors
Returns an error when required tables are missing or reconstruction cannot finish successfully.